# mamba4rec
[[Mamba]](https://huggingface.co/docs/transformers/main/model_doc/mamba) model for recommendation of  search suggests

[![Python version](https://img.shields.io/badge/Python-%3E=3.10-blue)](https://github.com/fkrasnov2/mamba4rec)


## Framework

[![Framework](https://github.com/fkrasnov2/mamba4rec/raw/main/mamba4recv3.png)](https://github.com/fkrasnov2/mamba4rec)

## Getting Started
bash:
```console
git clone https://github.com/fkrasnov2/mamba4rec.git
cd mamba4rec
#to test in isolated env
make install test
```
## Production ready
```bash
pip install mamba4rec
```

